@@ -3,6 +3,7 @@ from .get_me import get_me
 from .get_my_projects import get_my_projects
 from .push import push
 from .clone_content import clone_content
+from .build_latex import build_latex
 from .pull_as_latex import pull_as_latex
 from .build_pdf import build_pdf
 
@@ -13,6 +14,7 @@ app.command()(get_me)
 app.command()(get_my_projects)
 app.command()(push)
 app.command()(clone_content)
+app.command()(build_latex)
 app.command()(pull_as_latex)
 app.command()(build_pdf)
 
