@@ -87,7 +87,8 @@ TEMPLATES_URL = "{api_url}/templates"
 TEMPLATE_URL = "{api_url}/templates/{id}"
 TEMPLATE_DOWNLOAD_URL = "{api_url}/templates/{id}/download"
 
-METHODS = set(['get','post','patch'])
+METHODS = set(["get", "post", "patch"])
+
 
 class Session:
     def __init__(
@@ -660,20 +661,20 @@ class Session:
 
     def simple_auth_call(self, method: str, url: str, body: Optional[Dict] = None):
         """
-            Use the authenticated session to make a direct api call
+        Use the authenticated session to make a direct api call
         """
         if method not in METHODS:
-            raise ValueError(f'Unsupported method {method}')
+            raise ValueError(f"Unsupported method {method}")
 
-        if method == 'get':
+        if method == "get":
             return self._get(url)
-        elif method == 'post':
+        elif method == "post":
             if body is not None:
                 return self._post(url, body)
             else:
-                raise ValueError('Must post a body')
-        elif method == 'patch':
+                raise ValueError("Must post a body")
+        elif method == "patch":
             if body is not None:
                 return self._patch(url, body)
             else:
-                raise ValueError('Must patch a body')
+                raise ValueError("Must patch a body")
