@@ -144,10 +144,6 @@ class LatexArticle:
                 f"\\ref{{{ref_path}}}", f"\\ref{{{figures[0].marker}}}"
             )
 
-    def write(self, filepath: str):
-        with open(filepath, "w+") as file:
-            file.write(self.content)
-
     def _localize_authors(self, session: Session):
         logging.info("Localized authors")
         for author in self.authors:
