@@ -21,6 +21,16 @@ class LocalMarker(NamedTuple):
     remote_path: str
     content: Optional[str]
 
+    """
+        defining __eq__ and __hash__ is to allow the use of set()
+    """
+
+    def __eq__(self, other):
+        return self.marker == other.marker
+
+    def __hash__(self):
+        return hash(("marker", self.marker))
+
 
 # TODO move to session - easier to mock
 def get_model(session: Session, url: str, model: Type[BaseModel] = BlockVersion):
