@@ -19,16 +19,17 @@ IMAGE_LATEX_SNIPPET = rf"""\begin{{figure}}[ht]
 \end{{figure}}
 """
 
+
 def localize_image_from_top_level_block(
     session: Session,
     assets_folder: str,
     figure_list: List[LocalMarker],
-    version: BlockVersion
+    version: BlockVersion,
 ):
     """
-         - get the image block
-         - download the image to the assets_folder using teh local_path as name
-         - build the LaTeX content snippet and return it
+    - get the image block
+    - download the image to the assets_folder using teh local_path as name
+    - build the LaTeX content snippet and return it
     """
     try:
         oxa_path = version_id_to_oxa_path(version.id)
@@ -39,10 +40,10 @@ def localize_image_from_top_level_block(
         )
 
         figure = LocalMarker(
-            marker = get_fast_hash(),
-            local_path = local_path,
-            remote_path = oxa_path,
-            content=""
+            marker=get_fast_hash(),
+            local_path=local_path,
+            remote_path=oxa_path,
+            content="",
         )
         figure_list.append(figure)
 
