@@ -4,10 +4,22 @@ from .get_fast_hash import get_fast_hash
 
 
 BIBTEX_ENTRY_TYPES = [
-    "article", "book", "booklet", "conference", "inbook", "incollection",
-    "inproceedings", "manual", "mastersthesis", "misc", "phdthesis", "proceedings",
-    "techreport", "unpublished"
-    ]
+    "article",
+    "book",
+    "booklet",
+    "conference",
+    "inbook",
+    "incollection",
+    "inproceedings",
+    "manual",
+    "mastersthesis",
+    "misc",
+    "phdthesis",
+    "proceedings",
+    "techreport",
+    "unpublished",
+]
+
 
 def parse_cite_tag_from_bibtex(content: str):
     logging.debug("bibtex: %s", content)
